pub struct DataRecord {
pub id: String,
pub values: HashMap<String, DataValue>,
}Expand description
One row of typed values, addressable by field key.
Fields
id: Stringvalues: HashMap<String, DataValue>Implementations
Sourceimpl DataRecord
impl DataRecord
pub fn new( id: impl Into<String>, values: HashMap<String, DataValue>, ) -> DataRecord
Sourcepub fn from_text_map(
id: impl Into<String>,
cells: HashMap<String, String>,
) -> DataRecord
pub fn from_text_map( id: impl Into<String>, cells: HashMap<String, String>, ) -> DataRecord
Build a record from a string cell map (preview/demo convenience).
pub fn get(&self, field: &str) -> Option<&DataValue>