pub struct DataTableContext {Show 17 fields
pub features: DataTableFeatures,
pub selection_mode: Signal<Option<DataTableSelectionMode>>,
pub events: StoredValue<Option<DataTableEvents>>,
pub get_row_id: StoredValue<Option<GetRowId>>,
pub row_detail: StoredValue<Option<Arc<dyn Fn(DataRecord) -> AnyView + Send + Sync>>>,
pub auto_row_height: bool,
pub locale: StoredValue<DataTableLocale>,
pub pagination_display: StoredValue<PaginationDisplayFormat>,
pub page_size_options: StoredValue<Option<Vec<u32>>>,
pub get_row_class: StoredValue<Option<Callback<(DataTableRowModel, usize), String>>>,
pub direction: Signal<Direction>,
pub toolbar_config: StoredValue<DataTableToolbarConfig>,
pub header_chrome: StoredValue<DataTableHeaderChromeConfig>,
pub drag_column_field: RwSignal<Option<String>>,
pub column_drag_ghost: RwSignal<Option<ColumnDragGhost>>,
pub row_drag_ghost: RwSignal<Option<RowDragGhost>>,
pub drag_row_id: RwSignal<Option<String>>,
}Expand description
Context shared by crate::DataTable and composable subcomponents.
Fields
features: DataTableFeaturesselection_mode: Signal<Option<DataTableSelectionMode>>events: StoredValue<Option<DataTableEvents>>get_row_id: StoredValue<Option<GetRowId>>row_detail: StoredValue<Option<Arc<dyn Fn(DataRecord) -> AnyView + Send + Sync>>>auto_row_height: boollocale: StoredValue<DataTableLocale>pagination_display: StoredValue<PaginationDisplayFormat>page_size_options: StoredValue<Option<Vec<u32>>>get_row_class: StoredValue<Option<Callback<(DataTableRowModel, usize), String>>>direction: Signal<Direction>toolbar_config: StoredValue<DataTableToolbarConfig>header_chrome: StoredValue<DataTableHeaderChromeConfig>drag_column_field: RwSignal<Option<String>>Fallback drag source when dataTransfer is empty (e.g. synthetic DnD in tests).
column_drag_ghost: RwSignal<Option<ColumnDragGhost>>Floating label shown while a column is being drag-reordered.
row_drag_ghost: RwSignal<Option<RowDragGhost>>Full-row preview shown while a row is being drag-reordered.
drag_row_id: RwSignal<Option<String>>Fallback drag source for row reorder when dataTransfer is empty.