pub struct DataTableFeatures(/* private fields */);Expand description
Optional capabilities enabled on crate::DataTable.
Combine with | when multiple features are needed. Subcomponents document
which flag they require via Requires DataTableFeatures::… in rustdoc.
Implementations
Sourceimpl DataTableFeatures
impl DataTableFeatures
Sourcepub const COLUMN_PINNING: Self
pub const COLUMN_PINNING: Self
Pin columns left or right.
Sourcepub const COLUMN_REORDER: Self
pub const COLUMN_REORDER: Self
Drag-and-drop column reorder.
Sourcepub const ROW_PINNING: Self
pub const ROW_PINNING: Self
Pin rows top or bottom.
Sourcepub const ROW_REORDER: Self
pub const ROW_REORDER: Self
Drag-and-drop row reorder.
Sourcepub const ROW_DETAIL: Self
pub const ROW_DETAIL: Self
Expandable detail panel per row.
Sourcepub const VIRTUALIZATION: Self
pub const VIRTUALIZATION: Self
Row/column virtualization for large datasets.
Sourcepub const ROW_GROUPING: Self
pub const ROW_GROUPING: Self
Group rows by column values.
Sourcepub const AGGREGATION: Self
pub const AGGREGATION: Self
Footer/group aggregation functions.
Sourcepub const CELL_SELECTION: Self
pub const CELL_SELECTION: Self
Range cell selection like a spreadsheet.
Sourcepub const EXCEL_EXPORT: Self
pub const EXCEL_EXPORT: Self
Excel export (CSV/print always available).
Sourcepub const HEADER_FILTERS: Self
pub const HEADER_FILTERS: Self
Inline header row filters.
Sourcepub const MULTI_FILTER: Self
pub const MULTI_FILTER: Self
Multiple filters per column.
Sourcepub const MULTI_COLUMN_SORT: Self
pub const MULTI_COLUMN_SORT: Self
Multi-column sort.
Sourcepub const CHARTS_INTEGRATION: Self
pub const CHARTS_INTEGRATION: Self
Embed charts in grid cells/panels.
Sourceimpl DataTableFeatures
impl DataTableFeatures
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DataTableFeatures
impl DataTableFeatures
Sourcepub const fn iter(&self) -> Iter<DataTableFeatures>
pub const fn iter(&self) -> Iter<DataTableFeatures>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DataTableFeatures>
pub const fn iter_names(&self) -> IterNames<DataTableFeatures>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.