pub struct DataTableSlots {
pub toolbar: Option<DataTableToolbarSlot>,
pub footer: Option<DataTableFooterSlot>,
pub empty_view: Option<DataTableEmptyView>,
pub no_results_view: Option<DataTableNoResultsView>,
pub loading_view: Option<DataTableLoadingView>,
pub row_detail: Option<DataTableRowDetail>,
}Expand description
Internal slot content consumed by toolbar, footer, overlay, and row-detail subcomponents.
Fields
toolbar: Option<DataTableToolbarSlot>empty_view: Option<DataTableEmptyView>no_results_view: Option<DataTableNoResultsView>loading_view: Option<DataTableLoadingView>row_detail: Option<DataTableRowDetail>Implementations
Sourceimpl DataTableSlots
impl DataTableSlots
pub fn from_slot_props( toolbar: Option<DataTableToolbarSlot>, footer: Option<DataTableFooterSlot>, empty_view: Option<DataTableEmptyView>, no_results_view: Option<DataTableNoResultsView>, loading_view: Option<DataTableLoadingView>, row_detail: Option<DataTableRowDetail>, ) -> Self
Sourcepub fn row_detail_view(
&self,
legacy: Option<RowDetailView>,
) -> Option<RowDetailView>
pub fn row_detail_view( &self, legacy: Option<RowDetailView>, ) -> Option<RowDetailView>
Resolve row detail callback from slot or deprecated prop.