pub struct PinnedRowsState {
pub top: Vec<String>,
pub bottom: Vec<String>,
}Expand description
Sticky top/bottom row ids (resolved via crate::GetRowId when set).
Fields
top: Vec<String>Row ids sticky at the top of the scroll viewport.
bottom: Vec<String>Row ids sticky at the bottom of the scroll viewport.